@@ -1,4 +1,5 @@
 import datetime
+import http.client
 import io
 from io import BytesIO
 import logging
@@ -47,7 +48,7 @@ class Request:
                 self.connect_timeout = (0 if timeout.connect_timeout is Timeout.DEFAULT_TIMEOUT
                                         else timeout.connect_timeout)
                 self.read_timeout = (0 if timeout.read_timeout is Timeout.DEFAULT_TIMEOUT
-                                       else timeout.read_timeout)
+                                     else timeout.read_timeout)
             else:
                 self.connect_timeout, self.read_timeout = timeout
         else:
@@ -55,12 +56,12 @@ class Request:
 
         self.response_buffer = BytesIO()
         self.reason = None
-        self.headers = structures.CaseInsensitiveDict()
+        self.headers = http.client.HTTPMessage()
         self.reset_headers = False
 
     def header_function(self, line: bytes):
         if self.reset_headers:
-            self.headers = structures.CaseInsensitiveDict()
+            self.headers = http.client.HTTPMessage()
             self.reset_headers = False
 
         try:
@@ -82,7 +83,7 @@ class Request:
             return
 
         name, value = line.split(':', 1)
-        self.headers[name] = value.strip()
+        self.headers.add_header(name, value.strip())
 
     def send(self):
         try:
@@ -181,7 +182,9 @@ class Request:
         response.elapsed = elapsed
         response.status_code = status_code
         response.reason = self.reason
-        response.headers = self.headers
+        # Merge headers as allowed by RFC-7230 section 3.3.2
+        response.headers = structures.CaseInsensitiveDict(
+            ((k, ', '.join(self.headers.get_all(k))) for k in self.headers.keys()))
         response.encoding = self.headers.get_content_charset()
         response.url = self.prepared.url
         response.raw = self.response_buffer
